import { Action } from '@ngrx/store';
import { DiscoveryModeType } from '@overflow/model/discovery';
import { DiscoverySession } from '../../../core/discovery/discovery-session';
import { DiscoveryStatusType } from 'src/app/core/type';

export enum ActionType {
  RequestDiscover = '[app.discovery] RequestDiscover',

  RequestDiscoverStop = '[app.discovery] RequestDiscoverStop',

  ChangeDiscoveryMode = '[app.discovery] ChangeDiscoveryMode',
  ChangeDiscoveryStatus = '[app.discovery] ChangeDiscoveryStatus',

  DiscoveryComplete = '[app.discovery] DiscoveryComplete',
}


export class RequestDiscover implements Action {
  readonly type = ActionType.RequestDiscover;

  constructor(public payload: { discoverySession: DiscoverySession }) { }
}

export class ChangeDiscoveryMode implements Action {
  readonly type = ActionType.ChangeDiscoveryMode;

  constructor(public payload: { discoveryMode: DiscoveryModeType }) { }
}

export class RequestDiscoverStop implements Action {
  readonly type = ActionType.RequestDiscoverStop;

  constructor(public payload: { discoverySession: DiscoverySession }) { }
}

export class ChangeDiscoveryStatus implements Action {
  readonly type = ActionType.ChangeDiscoveryStatus;

  constructor(public payload: { discoveryStatus: DiscoveryStatusType }) { }
}

export class DiscoveryComplete implements Action {
  readonly type = ActionType.DiscoveryComplete;

  constructor() { }
}

export type Actions =
  | RequestDiscover
  | ChangeDiscoveryMode
  | RequestDiscoverStop
  | ChangeDiscoveryStatus
  | DiscoveryComplete
  ;
